Post Test
-----------------------------------------------------

Please try to solve each of the following problems. This test is **ungraded**. 
Please do not ask for external help and try your best to finish it! 
It is OK to not know the correct answers!

Problems
==============

.. selectquestion:: we-pp-post-1-Movie
   :fromid: Classes_Basic_Movie_fix_v3_ac
   :points: 10

.. selectquestion:: we-pp-post-2-Rectangle
   :fromid: Classes_Basic_Rectangle_ac_fix_v2
   :points: 10

.. selectquestion:: we-pp-post-3-Horse
   :fromid: Classes_Basic_Horse_v2_ac
   :points: 10

.. selectquestion:: we-pp-post-4-GasTank
   :fromid: Classes_Basic_GasTank_ac
   :points: 10

.. selectquestion:: we-pp-post-5-Dice
   :fromid: Classes_Basic_Dice_fix_v2_ac
   :points: 10


Thank You 🤗
============================
🎉 Thank you so much for taking part in this study! 

🙏 We appreciate your contribution to help more students become successful in computing courses in a low-cost, scalable, and easily
adopted way!!
